@@ -30,6 +30,7 @@ from hashlib import sha256
 from importlib import import_module
 from pathlib import Path
 from typing import Union, List, Optional
+from threading import Lock
 
 import telectron
 from telectron import raw
@@ -246,6 +247,8 @@ class Client(Methods, Scaffold):
 
         self.dispatcher = Dispatcher(self)
         self.loop = asyncio.get_event_loop()
+        self.albums = {}
+        self.album_lock = Lock()
 
     def __enter__(self):
         return self.start()
