@@ -869,6 +869,40 @@ def regex(pattern: Union[str, Pattern], flags: int = 0):
     )
 
 
+def text_exact(text: str):
+    """Filter updates that exactly match a given text.
+
+    Can be applied to handlers that receive one of the following updates:
+
+    - :obj:`~telectron.types.Message`: The filter will match ``text`` or ``caption``.
+    - :obj:`~telectron.types.CallbackQuery`: The filter will match ``data``.
+    - :obj:`~telectron.types.InlineQuery`: The filter will match ``query``.
+
+
+    Parameters:
+        text (``str``):
+            The text.
+    """
+
+    async def func(flt, _, update: Update):
+        if isinstance(update, Message):
+            value = update.text or update.caption
+        elif isinstance(update, CallbackQuery):
+            value = update.data
+        elif isinstance(update, InlineQuery):
+            value = update.query
+        else:
+            raise ValueError(f"Regex filter doesn't work with {type(update)}")
+
+        return bool(value == flt.t)
+
+    return create(
+        func,
+        "TextExactFilter",
+        t=text
+    )
+
+
 # noinspection PyPep8Naming
 class user(Filter, set):
     """Filter messages coming from one or more users.
