@@ -23,6 +23,8 @@ from telectron import raw
 from telectron import types
 from telectron import utils
 from ..object import Object
+from telectron.handlers.message_handler import MessageHandler
+from telectron.filters import all as all_filter, chat as chat_filter
 
 
 class Chat(Object):
@@ -999,3 +1001,17 @@ class Chat(Object):
             ``str``: On success, str is returned.
         """
         return self.title or self.full_name
+
+    def wait_for_message(self, filters=all_filter) -> str:
+        """shortcut for ```client.register_waiting(
+            MessageHandler,
+            filters.all(chat.id) & filters
+        )```
+
+        Returns:
+            ``WaitingResult``: On success, WaitingResult is returned.
+        """
+        return self._client.register_waiting(
+            MessageHandler,
+            chat_filter(self.id) & filters
+        )
